@@ -21,7 +21,7 @@
 //We need to include this before anything else, to avoid redefinitions:
 //#include <Python.h>
 
-#define NO_IMPORT_PYGOBJECT //To avoid a multiple definition in pygtk.
+//#define NO_IMPORT_PYGOBJECT //To avoid a multiple definition in pygtk.
 #include <pygobject.h> //For the PyGObject and PyGBoxed struct definitions.
 
 #include <libglom/python_embed/py_glom_record.h>
@@ -64,18 +64,10 @@ boost::python::object PyGlomRecord::get_connection()
 
   if(m_connection)
   {
-
     //Ask pygobject to create a PyObject* that wraps our GObject,
     //presumably using something from pygda:
-    if(!_PyGObject_API)
-    {
-      std::cerr << "pyggobject does not seem to be initialized properly." << std::endl;
-      return result;
-    }
-
     PyObject* cobject = pygobject_new( G_OBJECT(m_connection->gobj()) );
-    if(cobject)
-      result = boost::python::object( boost::python::borrowed(cobject) );
+    result = boost::python::object( boost::python::borrowed(cobject) );
   }
 
   return result;
@@ -146,7 +138,7 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   sharedptr<const Field> field = m_document->get_field(m_table_name, field_name);
   if(!field)
   {
-     std::cerr << "PyGlomRecord::setitem(): field=" << field_name << " not found in table=" << m_table_name << std::endl;
+     std::cerr << G_STRFUNC << ": field=" << field_name << " not found in table=" << m_table_name << std::endl;
      //TODO: Throw python exception.
      return;
   }
@@ -168,19 +160,19 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   else
     field_value = Conversions::get_empty_value(field_type);
 
-  //std::cout << "debug: PyGlomRecord::setitem(): field_name=" << field_name << ", field_type=" << field_type << ", field_value=" << field_value.to_string() << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": field_name=" << field_name << ", field_type=" << field_type << ", field_value=" << field_value.to_string() << std::endl;
 
 
   //Set the value in the database:
   if(!m_key_field || Conversions::value_is_empty(m_key_field_value))
   {
-    std::cerr << "PyGlomRecord::setitem(): The primary key name and value is not set. This would be a Glom bug." << std::endl;
+    std::cerr << G_STRFUNC << ": The primary key name and value is not set. This would be a Glom bug." << std::endl;
     return;
   }
 
   if(!m_connection)
   {
-    std::cerr << "PyGlomRecord::setitem(): The connection is null. This would be a Glom bug." << std::endl;
+    std::cerr << G_STRFUNC << ": The connection is null. This would be a Glom bug." << std::endl;
     return;
   }
 
@@ -188,7 +180,7 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   params->add_holder(field->get_holder(field_value));
   params->add_holder(m_key_field->get_holder(m_key_field_value));
 
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = 
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
   builder->set_table(m_table_name);
   builder->add_field_value_as_value(field->get_name(), field_value);
@@ -196,7 +188,7 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
     builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
       builder->add_field_id(m_key_field->get_name(), m_table_name),
       builder->add_expr(m_key_field_value)));
-
+ 
   bool updated = false;
   try
   {
@@ -204,18 +196,18 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   }
   catch(const Glib::Exception& ex)
   {
-    std::cerr << "PyGlomRecord::setitem(): exception while executing query: " << ex.what() << std::endl;
+    std::cerr << G_STRFUNC << ": exception while executing query: " << ex.what() << std::endl;
   }
   catch(const std::exception& ex)
   {
-    std::cerr << "PyGlomRecord::setitem(): exception while executing query: " << ex.what() << std::endl;
+    std::cerr << G_STRFUNC << ": exception while executing query: " << ex.what() << std::endl;
   }
 
   if(!updated)
   {
     Glib::ustring failed_query;
 
-    std::cerr << "PyGlomRecord::setitem(): UPDATE failed." << std::endl;
+    std::cerr << G_STRFUNC << ": UPDATE failed." << std::endl;
     /*
     if(stmt)
       failed_query = stmt->to_sql(params); //this throws too.
@@ -244,7 +236,7 @@ void PyGlomRecord::set_fields(const PyGlomRecord::type_map_field_values& field_v
   for(type_map_field_values::const_iterator iter = field_values.begin(); iter != field_values.end(); ++iter)
   {
     const Gnome::Gda::Value value = iter->second;
-    std::cout << "DEBUG: PyGlomRecord::set_fields(): field name=" << iter->first << ", type=" << g_type_name(value.get_value_type()) << std::endl;
+    std::cout << "debug: " << G_STRFUNC << ": field name=" << iter->first << ", type=" << g_type_name(value.get_value_type()) << std::endl;
   }
   */
 
