@@ -25,7 +25,6 @@
 #include "placeholder-glom.h"
 #include <gtkmm/messagedialog.h>
 #include <glom/application.h>
-#include <gdkmm.h>
 #include <glibmm/i18n.h>
 #include <string.h> // for memset
 
@@ -37,13 +36,6 @@ PlaceholderGlom::PlaceholderGlom() :
   Gtk::Widget()
 {
   set_has_window(false);
-#ifndef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
-  signal_realize().connect(sigc::mem_fun(*this, &PlaceholderGlom::on_realize));
-  signal_unrealize().connect(sigc::mem_fun(*this, &PlaceholderGlom::on_unrealize));
-  signal_expose_event().connect(sigc::mem_fun(*this, &PlaceholderGlom::on_expose_event));
-  signal_size_request().connect(sigc::mem_fun(*this, &PlaceholderGlom::on_size_request));
-  signal_size_allocate().connect(sigc::mem_fun(*this, &PlaceholderGlom::on_size_allocate));
-#endif
 }
 
 PlaceholderGlom::~PlaceholderGlom()
@@ -83,12 +75,7 @@ void PlaceholderGlom::on_size_allocate(Gtk::Allocation& allocation)
 void PlaceholderGlom::on_realize()
 {
   //Call base class:
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   Gtk::Widget::on_realize();
-#endif
-
-  ensure_style();
-
 
   if(!m_refGdkWindow)
   {
@@ -115,7 +102,7 @@ void PlaceholderGlom::on_realize()
     set_window(m_refGdkWindow);
 
     //set colors
-    modify_fg(Gtk::STATE_NORMAL , Gdk::Color("black"));
+    override_color(Gdk::RGBA("black"));
 
     //make the widget receive expose events
     m_refGdkWindow->set_user_data(gobj());
@@ -125,35 +112,20 @@ void PlaceholderGlom::on_realize()
 void PlaceholderGlom::on_unrealize()
 {
   m_refGdkWindow.reset();
-#ifdef GLIBMM_DEFAULT_SIGNAL_HANDLERS_ENABLED
   Gtk::Widget::on_unrealize();
-#endif
 }
 
-bool PlaceholderGlom::on_expose_event(GdkEventExpose* event)
+bool PlaceholderGlom::on_draw(const Cairo::RefPtr<Cairo::Context>& cr)
 {
-  if(m_refGdkWindow)
-  {
-    Cairo::RefPtr<Cairo::Context> cr = m_refGdkWindow->create_cairo_context();
-    if(event)
-    {
-      // clip to the area that needs to be re-exposed so we don't draw any
-      // more than we need to.
-      cr->rectangle(event->area.x, event->area.y,
-              event->area.width, event->area.height);
-      cr->clip();
-    }
+  // Paint the background:
+  Gdk::Cairo::set_source_rgba(cr, get_style_context()->get_background_color());
+  cr->paint();
 
-    // Paint the background:
-    Gdk::Cairo::set_source_color(cr, get_style()->get_bg(Gtk::STATE_NORMAL));
-    cr->paint();
-
-    // Draw the foreground:
-    Gdk::Cairo::set_source_color(cr, get_style()->get_fg(Gtk::STATE_NORMAL));
-    cr->set_line_width(4);
-    cr->rectangle(0, 0,  get_allocation().get_width(), get_allocation().get_height());
-    cr->stroke();
-  }
+  // Draw the foreground:
+  Gdk::Cairo::set_source_rgba(cr, get_style_context()->get_color());
+  cr->set_line_width(4);
+  cr->rectangle(0, 0,  get_allocation().get_width(), get_allocation().get_height());
+  cr->stroke();
 
   return true;
 }
